@@ -84,6 +84,7 @@ class CategoriaOrdenPago(str, Enum):
     odps_canceladas_local_respuesta = 'ODPS_CANCELADAS_LOCAL_RESPUESTA'
     odps_canceladas_x_banxico = 'ODPS_CANCELADAS_X_BANXICO'
     odps_canceladas_x_banxico_respuesta = 'ODPS_CANCELADAS_X_BANXICO_RESPUESTA'
+    ensesion_respuesta = 'ENSESION_RESPUESTA'
 
 
 class EstadoOrdenPago(str, Enum):
@@ -91,6 +92,7 @@ class EstadoOrdenPago(str, Enum):
     liberada = 'L'
     capturada = 'C'
     autorizada = 'A'
+    cancelada = 'CN'
 
 
 class ClaveOrdenanteOrdenPago(int, Enum):
